@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2004 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : AudioSource.cpp
-   Version  : $Revision: 1.3 $
+   Version  : $Revision: 400 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/AudioSource.cpp,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -46,7 +46,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: AudioSource.cpp,v 1.3 2005/04/04 08:36:16 darkeye Exp $";
+static const char fileid[] = "$Id: AudioSource.cpp 400 2007-02-25 17:04:17Z darkeye $";
 
 
 /* ===============================================  local function prototypes */
@@ -66,7 +66,20 @@ AudioSource :: createDspSource( const char    * deviceName,
                                                             throw ( Exception )
 {
     
-    if ( Util::strEq( deviceName, "/dev", 4) ) {
+    if ( Util::strEq( deviceName, "/dev/tty", 8) ) {
+#if defined( SUPPORT_SERIAL_ULAW )
+        Reporter::reportEvent( 1, "Using Serial Ulaw input device:",
+                                  deviceName);
+        return new SerialUlaw( deviceName,
+                                 sampleRate,
+                                 bitsPerSample,
+                                 channel);
+#else
+        throw Exception( __FILE__, __LINE__,
+                             "trying to open Serial ULaw device "
+                             "without support compiled", deviceName);
+#endif
+	} else if ( Util::strEq( deviceName, "/dev", 4) ) {
 #if defined( SUPPORT_OSS_DSP )
         Reporter::reportEvent( 1, "Using OSS DSP input device:", deviceName);
         return new OssDspSource( deviceName,
@@ -111,22 +124,3 @@ AudioSource :: createDspSource( const char    * deviceName,
     }
 }
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/AudioSource.cpp,v $
-
-  $Log: AudioSource.cpp,v $
-  Revision 1.3  2005/04/04 08:36:16  darkeye
-  commited changes to enable Jack support
-  thanks to Nicholas J. Humfrey, njh@ecs.soton.ac.uk
-
-  Revision 1.2  2004/02/15 22:26:16  darkeye
-  fixed typo, minimal cosmetic change
-
-  Revision 1.1  2004/02/15 12:06:29  darkeye
-  added ALSA support, thanks to Christian Forster
-
-
-------------------------------------------------------------------------------*/
-
