@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : AudioSource.h
-   Version  : $Revision: 1.9 $
+   Version  : $Revision: 400 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/AudioSource.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -71,10 +71,15 @@
 #define SUPPORT_JACK_DSP 1
 #endif
 
+#if defined ( HAVE_TERMIOS_H )
+#define SUPPORT_SERIAL_ULAW 1
+#endif
+
 #if !defined( SUPPORT_ALSA_DSP ) \
     && !defined( SUPPORT_OSS_DSP ) \
     && !defined( SUPPORT_JACK_DSP ) \
-    && !defined( SUPPORT_SOLARIS_DSP )
+    && !defined( SUPPORT_SOLARIS_DSP ) \
+    && !defined( SUPPORT_SERIAL_ULAW)
 // there was no DSP audio system found
 #error No DSP audio input device found on system
 #endif
@@ -86,7 +91,7 @@
  *  Audio data input
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.9 $
+ *  @version $Revision: 400 $
  */
 class AudioSource : public Source, public virtual Reporter
 {
@@ -295,46 +300,14 @@ class AudioSource : public Source, public virtual Reporter
 #include "JackDspSource.h"
 #endif
 
+#if defined ( SUPPORT_SERIAL_ULAW )
+#include "SerialUlaw.h"
+#endif
+
+
 /* ====================================================== function prototypes */
 
 
 
 #endif  /* AUDIO_SOURCE_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/AudioSource.h,v $
-
-  $Log: AudioSource.h,v $
-  Revision 1.9  2005/04/14 11:53:17  darkeye
-  fixed API documentation issues
-
-  Revision 1.8  2005/04/04 08:36:16  darkeye
-  commited changes to enable Jack support
-  thanks to Nicholas J. Humfrey, njh@ecs.soton.ac.uk
-
-  Revision 1.7  2004/02/18 21:08:11  darkeye
-  ported to OpenBSD (real-time scheduling not yet supported)
-
-  Revision 1.6  2004/02/15 12:06:29  darkeye
-  added ALSA support, thanks to Christian Forster
-
-  Revision 1.5  2001/09/18 14:57:19  darkeye
-  finalized Solaris port
-
-  Revision 1.4  2001/09/11 15:05:21  darkeye
-  added Solaris support
-
-  Revision 1.3  2000/11/12 13:31:40  darkeye
-  added kdoc-style documentation comments
-
-  Revision 1.2  2000/11/05 17:37:24  darkeye
-  removed clone() functions
-
-  Revision 1.1.1.1  2000/11/05 10:05:47  darkeye
-  initial version
-
-  
-------------------------------------------------------------------------------*/
-
