@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : DarkIce.cpp
-   Version  : $Revision: 1.49 $
+   Version  : $Revision: 410 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
+   Location : $HeadURL$
    
 
    Copyright notice:
@@ -105,7 +105,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: DarkIce.cpp,v 1.49 2006/03/23 09:34:57 darkeye Exp $";
+static const char fileid[] = "$Id: DarkIce.cpp 410 2007-04-26 08:22:45Z darkeye $";
 
 
 /*------------------------------------------------------------------------------
@@ -240,6 +240,7 @@ DarkIce :: configIceCast (  const Config      & config,
         const char                * localDumpName   = 0;
         FileSink                  * localDumpFile   = 0;
         bool                        fileAddDate     = false;
+        const char                * fileDateFormat  = 0;
 
         str         = cs->get( "sampleRate");
         sampleRate  = str ? Util::strToL( str) : dsp->getSampleRate();
@@ -306,6 +307,7 @@ DarkIce :: configIceCast (  const Config      & config,
         highpass    = str ? Util::strToL( str) : 0;
         str         = cs->get("fileAddDate");
         fileAddDate = str ? (Util::strEq( str, "yes") ? true : false) : false;
+        fileDateFormat = cs->get("fileDateFormat");
 
         localDumpName = cs->get( "localDumpFile");
 
@@ -314,10 +316,16 @@ DarkIce :: configIceCast (  const Config      & config,
         // check for and create the local dump file if needed
         if ( localDumpName != 0 ) {
             if ( fileAddDate ) {
-                localDumpName = Util::fileAddDate(localDumpName);
+                if (fileDateFormat == 0) {
+                    localDumpName = Util::fileAddDate(localDumpName);
+                }
+                else {
+                    localDumpName = Util::fileAddDate(  localDumpName,
+                                                        fileDateFormat );
+                }
             }
 
-            localDumpFile = new FileSink( localDumpName);
+            localDumpFile = new FileSink( stream, localDumpName);
             if ( !localDumpFile->exists() ) {
                 if ( !localDumpFile->create() ) {
                     reportEvent( 1, "can't create local dump file",
@@ -432,6 +440,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
         const char                * localDumpName   = 0;
         FileSink                  * localDumpFile   = 0;
         bool                        fileAddDate     = false;
+        const char                * fileDateFormat  = 0;
 
         str         = cs->getForSure( "format", " missing in section ", stream);
         if ( Util::strEq( str, "vorbis") ) {
@@ -508,6 +517,7 @@ DarkIce :: configIceCast2 (  const Config      & config,
         highpass    = str ? Util::strToL( str) : 0;
         str         = cs->get( "fileAddDate");
         fileAddDate = str ? (Util::strEq( str, "yes") ? true : false) : false;
+        fileDateFormat = cs->get( "fileDateFormat");
         
         localDumpName = cs->get( "localDumpFile");
 
@@ -516,10 +526,16 @@ DarkIce :: configIceCast2 (  const Config      & config,
         // check for and create the local dump file if needed
         if ( localDumpName != 0 ) {
             if ( fileAddDate ) {
-                localDumpName = Util::fileAddDate(localDumpName);
+                if (fileDateFormat == 0) {
+                    localDumpName = Util::fileAddDate(localDumpName);
+                }
+                else {
+                    localDumpName = Util::fileAddDate(  localDumpName,
+                                                        fileDateFormat );
+                }
             }
 
-            localDumpFile = new FileSink( localDumpName);
+            localDumpFile = new FileSink( stream, localDumpName);
             if ( !localDumpFile->exists() ) {
                 if ( !localDumpFile->create() ) {
                     reportEvent( 1, "can't create local dump file",
@@ -689,6 +705,7 @@ DarkIce :: configShoutCast (    const Config      & config,
         const char                * localDumpName   = 0;
         FileSink                  * localDumpFile   = 0;
         bool                        fileAddDate     = false;
+        const char                * fileDateFormat  = 0;
 
         str         = cs->get( "sampleRate");
         sampleRate  = str ? Util::strToL( str) : dsp->getSampleRate();
@@ -751,6 +768,7 @@ DarkIce :: configShoutCast (    const Config      & config,
         icq         = cs->get( "icq");
         str         = cs->get("fileAddDate");
         fileAddDate = str ? (Util::strEq( str, "yes") ? true : false) : false;
+        fileDateFormat = cs->get( "fileDateFormat");
 
         localDumpName = cs->get( "localDumpFile");
 
@@ -759,10 +777,16 @@ DarkIce :: configShoutCast (    const Config      & config,
         // check for and create the local dump file if needed
         if ( localDumpName != 0 ) {
             if ( fileAddDate ) {
-                localDumpName = Util::fileAddDate(localDumpName);
+                if (fileDateFormat == 0) {
+                    localDumpName = Util::fileAddDate(localDumpName);
+                }
+                else {
+                    localDumpName = Util::fileAddDate(  localDumpName,
+                                                        fileDateFormat );
+                }
             }
 
-            localDumpFile = new FileSink( localDumpName);
+            localDumpFile = new FileSink( stream, localDumpName);
             if ( !localDumpFile->exists() ) {
                 if ( !localDumpFile->create() ) {
                     reportEvent( 1, "can't create local dump file",
@@ -841,6 +865,8 @@ DarkIce :: configFileCast (  const Config      & config )
         unsigned int                sampleRate      = 0;
         int                         lowpass         = 0;
         int                         highpass        = 0;
+        bool                        fileAddDate     = false;
+        const char                * fileDateFormat  = 0;
 
         format      = cs->getForSure( "format", " missing in section ", stream);
         if ( !Util::strEq( format, "vorbis")
@@ -856,6 +882,11 @@ DarkIce :: configFileCast (  const Config      & config )
         targetFileName    = cs->getForSure( "fileName",
                                             " missing in section ",
                                             stream);
+
+        str         = cs->get( "fileAddDate");
+        fileAddDate = str ? (Util::strEq( str, "yes") ? true : false) : false;
+        fileDateFormat = cs->get( "fileDateFormat");
+
         str         = cs->get( "sampleRate");
         sampleRate  = str ? Util::strToL( str) : dsp->getSampleRate();
 
@@ -907,7 +938,17 @@ DarkIce :: configFileCast (  const Config      & config )
         // go on and create the things
 
         // the underlying file
-        FileSink  * targetFile = new FileSink( targetFileName);
+        if ( fileAddDate ) {
+            if (fileDateFormat == 0) {
+                targetFileName = Util::fileAddDate( targetFileName);
+            }
+            else {
+                targetFileName = Util::fileAddDate( targetFileName,
+                                                    fileDateFormat );
+            }
+        }
+
+        FileSink  * targetFile = new FileSink( stream, targetFileName);
         if ( !targetFile->exists() ) {
             if ( !targetFile->create() ) {
                 throw Exception( __FILE__, __LINE__,
@@ -964,6 +1005,7 @@ DarkIce :: configFileCast (  const Config      & config )
                                                     dsp.get(),
                                                     bitrateMode,
                                                     bitrate,
+                                                    quality,
                                                     dsp->getSampleRate(),
                                                     dsp->getChannel() );
 #endif // HAVE_VORBIS_LIB
@@ -996,43 +1038,40 @@ DarkIce :: configFileCast (  const Config      & config )
 
 
 /*------------------------------------------------------------------------------
- *  Set POSIX real-time scheduling, if super-user
+ *  Set POSIX real-time scheduling
  *----------------------------------------------------------------------------*/
 void
 DarkIce :: setRealTimeScheduling ( void )               throw ( Exception )
 {
 // Only if the OS has the POSIX real-time scheduling functions implemented.
 #if defined( HAVE_SCHED_GETSCHEDULER ) && defined( HAVE_SCHED_GETPARAM )
-    uid_t   euid;
+    int                 high_priority;
+    struct sched_param  param;
 
-    euid = geteuid();
+    /* store the old scheduling parameters */
+    if ( (origSchedPolicy = sched_getscheduler(0)) == -1 ) {
+        throw Exception( __FILE__, __LINE__, "sched_getscheduler", errno);
+    }
 
-    if ( euid == 0 ) {
-        int                 high_priority;
-        struct sched_param  param;
+    if ( sched_getparam( 0, &param) == -1 ) {
+        throw Exception( __FILE__, __LINE__, "sched_getparam", errno);
+    }
+    origSchedPriority = param.sched_priority;
+    
+    /* set SCHED_FIFO with max - 1 priority */
+    if ( (high_priority = sched_get_priority_max(SCHED_FIFO)) == -1 ) {
+        throw Exception(__FILE__,__LINE__,"sched_get_priority_max",errno);
+    }
+    reportEvent( 8, "scheduler high priority", high_priority);
 
-        /* store the old scheduling parameters */
-        if ( (origSchedPolicy = sched_getscheduler(0)) == -1 ) {
-            throw Exception( __FILE__, __LINE__, "sched_getscheduler", errno);
-        }
-
-        if ( sched_getparam( 0, &param) == -1 ) {
-            throw Exception( __FILE__, __LINE__, "sched_getparam", errno);
-        }
-        origSchedPriority = param.sched_priority;
-        
-        /* set SCHED_FIFO with max - 1 priority */
-        if ( (high_priority = sched_get_priority_max(SCHED_FIFO)) == -1 ) {
-            throw Exception(__FILE__,__LINE__,"sched_get_priority_max",errno);
-        }
-        reportEvent( 8, "scheduler high priority", high_priority);
-
-        param.sched_priority = high_priority - 1;
-
-        if ( sched_setscheduler( 0, SCHED_FIFO, &param) == -1 ) {
-            throw Exception( __FILE__, __LINE__, "sched_setscheduler", errno);
-        }
+    param.sched_priority = high_priority - 1;
 
+    if ( sched_setscheduler( 0, SCHED_FIFO, &param) == -1 ) {
+        reportEvent( 1,
+                     "Could not set POSIX real-time scheduling, "
+                     "this may cause recording skips.\n"
+                     "Try to run darkice as the super-user.");
+    } else {
         /* ask the new priortiy and report it */
         if ( sched_getparam( 0, &param) == -1 ) {
             throw Exception( __FILE__, __LINE__, "sched_getparam", errno);
@@ -1041,11 +1080,6 @@ DarkIce :: setRealTimeScheduling ( void )               throw ( Exception )
         reportEvent( 1,
                      "Using POSIX real-time scheduling, priority",
                      param.sched_priority );
-    } else {
-        reportEvent( 1,
-        "Not running as super-user, unable to use POSIX real-time scheduling" );
-        reportEvent( 1,
-        "It is recommended that you run this program as super-user");
     }
 #else
     reportEvent( 1, "POSIX scheduling not supported on this system, "
@@ -1137,171 +1171,15 @@ DarkIce :: run ( void )                             throw ( Exception )
 
 
 /*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/DarkIce.cpp,v $
+ *  Tell each sink to cut what they are doing, and start again.
+ *----------------------------------------------------------------------------*/
+void
+DarkIce :: cut ( void )                             throw ()
+{
+    reportEvent( 5, "cutting");
 
-  $Log: DarkIce.cpp,v $
-  Revision 1.49  2006/03/23 09:34:57  darkeye
-  fixed checking for mp3 and mp2 lib support for icecast-1.x streams
+    encConnector->cut();
 
-  Revision 1.48  2006/01/27 15:02:05  darkeye
-  fixued issue of compiling without lame, but with twolame
-
-  Revision 1.47  2006/01/25 22:47:15  darkeye
-  added mpeg2 support, thanks to Nicholas J Humfrey
-
-  Revision 1.46  2006/01/19 16:09:05  darkeye
-  added check for bufferSecs setting not to be 0
-
-  Revision 1.45  2005/10/22 10:34:21  darkeye
-  added highpass and lowpass values to icecast2 sections
-
-  Revision 1.44  2005/04/16 21:57:34  darkeye
-  added AAC support through the faac codec, http://www.audiocoding.com/
-
-  Revision 1.43  2005/04/11 19:27:43  darkeye
-  added option to turn off automatic reconnect feature
-
-  Revision 1.42  2005/04/04 08:36:17  darkeye
-  commited changes to enable Jack support
-  thanks to Nicholas J. Humfrey, njh@ecs.soton.ac.uk
-
-  Revision 1.41  2005/04/03 05:12:20  jbebel
-  Changed mechanism for testing the presence of the quality value such that
-  zero is a valid option.
-
-  Revision 1.40  2004/02/23 19:12:51  darkeye
-  ported to NetBSD
-
-  Revision 1.39  2004/02/19 06:47:06  darkeye
-  finalized OpenBSD port
-
-  Revision 1.38  2004/02/18 21:08:11  darkeye
-  ported to OpenBSD (real-time scheduling not yet supported)
-
-  Revision 1.37  2004/02/15 12:14:38  darkeye
-  added patch to allow mp3 stream downsampling to mono for icecast2 as well
-
-  Revision 1.36  2004/02/15 12:06:30  darkeye
-  added ALSA support, thanks to Christian Forster
-
-  Revision 1.35  2003/02/09 13:15:57  darkeye
-  added feature for setting the TITLE comment field for vorbis streams
-
-  Revision 1.34  2003/02/09 12:57:36  darkeye
-  cosmetic changes to the fileAddDate option
-
-  Revision 1.33  2002/11/20 16:52:05  wandereq
-  added fileAddDate function
-
-  Revision 1.32  2002/10/19 12:24:55  darkeye
-  anged internals so that now each encoding/server connection is
-  a separate thread
-
-  Revision 1.31  2002/08/20 19:35:37  darkeye
-  added possibility to specify maximum bitrate for Ogg Vorbis streams
-
-  Revision 1.30  2002/08/20 18:37:49  darkeye
-  added mp3 streaming possibility for icecast2
-
-  Revision 1.29  2002/08/03 12:41:18  darkeye
-  added possibility to stream in mono when recording in stereo
-
-  Revision 1.28  2002/07/20 10:59:00  darkeye
-  added support for Ogg Vorbis 1.0, removed support for rc2
-
-  Revision 1.27  2002/04/13 11:26:00  darkeye
-  added cbr, abr and vbr setting feature with encoding quality
-
-  Revision 1.26  2002/03/28 16:43:11  darkeye
-  enabled resampling and variable bitrates for vorbis (icecast2) streams
-
-  Revision 1.25  2002/02/28 09:49:25  darkeye
-  added possibility to save the encoded stream to a local file only
-  (no streaming server needed)
-
-  Revision 1.24  2002/02/20 11:54:11  darkeye
-  added local dump file possibility
-
-  Revision 1.23  2002/02/20 10:35:35  darkeye
-  updated to work with Ogg Vorbis libs rc3 and current IceCast2 cvs
-
-  Revision 1.22  2001/10/20 10:56:45  darkeye
-  added possibility to disable highpass and lowpass filters for lame
-
-  Revision 1.21  2001/10/19 12:39:42  darkeye
-  created configure options to compile with or without lame / Ogg Vorbis
-
-  Revision 1.20  2001/10/19 09:03:39  darkeye
-  added support for resampling mp3 streams
-
-  Revision 1.19  2001/09/14 19:31:06  darkeye
-  added IceCast2 / vorbis support
-
-  Revision 1.18  2001/09/11 15:05:21  darkeye
-  added Solaris support
-
-  Revision 1.17  2001/09/09 11:27:31  darkeye
-  added support for ShoutCast servers
-
-  Revision 1.16  2001/09/05 20:11:15  darkeye
-  removed dependency on locally stored SGI STL header files
-  now compiler-supplied C++ library STL header files are used
-  compiles under GNU C++ 3
-  hash_map (an SGI extension to STL) replaced with map
-  std:: namespace prefix added to all STL class references
-
-  Revision 1.15  2001/08/30 17:25:56  darkeye
-  renamed configure.h to config.h
-
-  Revision 1.14  2001/08/29 21:08:30  darkeye
-  made some description options in the darkice config file optional
-
-  Revision 1.13  2001/08/26 20:44:30  darkeye
-  removed external command-line encoder support
-  replaced it with a shared-object support for lame with the possibility
-  of static linkage
-
-  Revision 1.12  2000/12/20 12:36:47  darkeye
-  added POSIX real-time scheduling
-
-  Revision 1.11  2000/11/18 11:13:27  darkeye
-  removed direct reference to cout, except from main.cpp
-  all class use the Reporter interface to report events
-
-  Revision 1.10  2000/11/17 15:50:48  darkeye
-  added -Wall flag to compiler and eleminated new warnings
-
-  Revision 1.9  2000/11/15 18:37:37  darkeye
-  changed the transferable number of bytes to unsigned long
-
-  Revision 1.8  2000/11/15 18:08:43  darkeye
-  added multiple verbosity-level event reporting and verbosity command
-  line option
-
-  Revision 1.7  2000/11/13 19:38:55  darkeye
-  moved command line parameter parsing from DarkIce.cpp to main.cpp
-
-  Revision 1.6  2000/11/13 18:46:50  darkeye
-  added kdoc-style documentation comments
-
-  Revision 1.5  2000/11/10 20:16:21  darkeye
-  first real tests with multiple streaming
-
-  Revision 1.4  2000/11/09 22:09:46  darkeye
-  added multiple outputs
-  added configuration reading
-  added command line processing
-
-  Revision 1.3  2000/11/08 17:29:50  darkeye
-  added configuration file reader
-
-  Revision 1.2  2000/11/05 14:08:27  darkeye
-  changed builting to an automake / autoconf environment
-
-  Revision 1.1.1.1  2000/11/05 10:05:49  darkeye
-  initial version
-
-  
-------------------------------------------------------------------------------*/
+    reportEvent( 5, "cutting ends");
+}
 
