@@ -1,13 +1,15 @@
 /*------------------------------------------------------------------------------
 
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
+
    Copyright (c) 2005 Nicholas Humfrey. All rights reserved.
 
    Tyrell DarkIce
 
    File     : JackDspSource.h
-   Version  : $Revision: 1.2 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/JackDspSource.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -60,7 +62,7 @@
  *  An audio input based on JACK
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.2 $
+ *  @version $Revision: 394 $
  */
 class JackDspSource : public AudioSource, public virtual Reporter
 {
@@ -274,19 +276,3 @@ class JackDspSource : public AudioSource, public virtual Reporter
 
 #endif  /* JACK_DSP_SOURCE_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/JackDspSource.h,v $
-
-  $Log: JackDspSource.h,v $
-  Revision 1.2  2005/04/14 11:53:17  darkeye
-  fixed API documentation issues
-
-  Revision 1.1  2005/04/04 08:36:17  darkeye
-  commited changes to enable Jack support
-  thanks to Nicholas J. Humfrey, njh@ecs.soton.ac.uk
-
-  
-------------------------------------------------------------------------------*/
-
