@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : MultiThreadedConnector.h
-   Version  : $Revision: 1.5 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/MultiThreadedConnector.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -69,7 +69,7 @@
  *  producer - consumer approach.
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.5 $
+ *  @version $Revision: 394 $
  */
 class MultiThreadedConnector : public virtual Connector
 {
@@ -107,6 +107,12 @@ class MultiThreadedConnector : public virtual Connector
                  */
                 bool                        isDone;
 
+                /**
+                 *  A flag to show that the sink should be made to cut in the
+                 *  next iteration.
+                 */
+                bool                    cut;
+
                 /**
                  *  Default constructor.
                  */
@@ -118,6 +124,7 @@ class MultiThreadedConnector : public virtual Connector
                     this->thread    = 0;
                     this->accepting = false;
                     this->isDone    = false;
+                    this->cut       = false;
                 }
 
                 /**
@@ -313,6 +320,15 @@ class MultiThreadedConnector : public virtual Connector
                     unsigned int        sec,
                     unsigned int        usec )          throw ( Exception );
 
+        /**
+         *  Signal to each sink we have that they need to cut what they are
+         *  doing, and start again. For FileSinks, this usually means to
+         *  save the archive file recorded so far, and start a new archive
+         *  file.
+         */
+        virtual void
+        cut ( void )                                throw ();
+
         /**
          *  Close the Connector. The Source and all Sinks are closed.
          *
@@ -322,7 +338,7 @@ class MultiThreadedConnector : public virtual Connector
         close ( void )                                  throw ( Exception );
 
         /**
-         *  This is the function for each thread.
+         *  This is the worker function for each thread.
          *  This function has to return fast
          *
          *  @param ixSink the index of the sink this thread works on.
@@ -341,30 +357,3 @@ class MultiThreadedConnector : public virtual Connector
 
 #endif  /* MULTI_THREADED_CONNECTOR_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/MultiThreadedConnector.h,v $
-
-  $Log: MultiThreadedConnector.h,v $
-  Revision 1.5  2005/04/11 19:27:43  darkeye
-  added option to turn off automatic reconnect feature
-
-  Revision 1.4  2004/02/23 19:12:52  darkeye
-  ported to NetBSD
-
-  Revision 1.3  2002/11/26 21:41:20  darkeye
-  bugfix: MultiThreadedConnector::sinkThread() was private, now public
-
-  Revision 1.2  2002/10/19 13:35:21  darkeye
-  when a connection is dropped, DarkIce tries to reconnect, indefinitely
-  removed extreme event reporting for thread-related events
-
-  Revision 1.1  2002/10/19 12:25:47  darkeye
-  changed internals so that now each encoding/server connection is
-  a separate thread
-
-
-  
-------------------------------------------------------------------------------*/
-
