@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : ShoutCast.cpp
-   Version  : $Revision: 1.3 $
+   Version  : $Revision: 411 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/ShoutCast.cpp,v $
+   Location : $Source$
    
    Copyright notice:
 
@@ -67,7 +67,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: ShoutCast.cpp,v 1.3 2002/05/28 12:35:41 darkeye Exp $";
+static const char fileid[] = "$Id: ShoutCast.cpp 411 2007-04-26 08:32:56Z darkeye $";
 
 
 /*------------------------------------------------------------------------------
@@ -140,6 +140,20 @@ ShoutCast :: sendLogin ( void )                           throw ( Exception )
     sink->write( str, strlen( str));
     sink->flush();
 
+    /* read the anticipated response: "OK" */
+    len = source->read( resp, STRBUF_SIZE);
+    reportEvent(8, "server response length: ", len);
+    reportEvent(8, "server response: ", resp);
+    if ( len < 2 || resp[0] != 'O' || resp[1] != 'K' ) {
+        return false;
+    }
+
+    /* suck anything that the other side has to say */
+    while ( source->canRead( 0, 0) && 
+           (len = source->read( resp, STRBUF_SIZE)) ) {
+        ;
+    }
+
     /* send the icy headers */
     if ( getName() ) {
         str = "icy-name:";
@@ -201,38 +215,7 @@ ShoutCast :: sendLogin ( void )                           throw ( Exception )
     sink->write( str, strlen( str));
     sink->flush();
 
-    /* read the anticipated response: "OK" */
-    len = source->read( resp, STRBUF_SIZE);
-    if ( len < 2 || resp[0] != 'O' || resp[1] != 'K' ) {
-        return false;
-    }
-
-    /* suck anything that the other side has to say */
-    while ( source->canRead( 0, 0) && 
-           (len = source->read( resp, STRBUF_SIZE)) ) {
-        ;
-    }
-
     return true;
 }
 
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/ShoutCast.cpp,v $
-
-  $Log: ShoutCast.cpp,v $
-  Revision 1.3  2002/05/28 12:35:41  darkeye
-  code cleanup: compiles under gcc-c++ 3.1, using -pedantic option
-
-  Revision 1.2  2001/11/20 09:06:18  darkeye
-  fixed public stream reporting
-
-  Revision 1.1  2001/09/09 11:27:31  darkeye
-  added support for ShoutCast servers
-
-
-  
-------------------------------------------------------------------------------*/
-
