@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : ShoutCast.h
-   Version  : $Revision: 1.3 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/ShoutCast.h,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -54,7 +54,7 @@
  *  icy login
  *
  *  @author  $Author: darkeye $
- *  @version $Revision: 1.3 $
+ *  @version $Revision: 394 $
  */
 class ShoutCast : public CastSink
 {
@@ -255,22 +255,3 @@ class ShoutCast : public CastSink
 
 #endif  /* SHOUT_CAST_H */
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/ShoutCast.h,v $
-
-  $Log: ShoutCast.h,v $
-  Revision 1.3  2005/04/14 11:53:17  darkeye
-  fixed API documentation issues
-
-  Revision 1.2  2002/02/20 11:54:11  darkeye
-  added local dump file possibility
-
-  Revision 1.1  2001/09/09 11:27:31  darkeye
-  added support for ShoutCast servers
-
-
-  
-------------------------------------------------------------------------------*/
-
