@@ -1,13 +1,13 @@
 /*------------------------------------------------------------------------------
 
-   Copyright (c) 2000 Tyrell Corporation. All rights reserved.
+   Copyright (c) 2000-2007 Tyrell Corporation. All rights reserved.
 
    Tyrell DarkIce
 
    File     : SolarisDspSource.cpp
-   Version  : $Revision: 1.2 $
+   Version  : $Revision: 394 $
    Author   : $Author: darkeye $
-   Location : $Source: /cvsroot/darkice/darkice/src/SolarisDspSource.cpp,v $
+   Location : $HeadURL$
    
    Copyright notice:
 
@@ -80,6 +80,12 @@
 #error need sys/ioctl.h
 #endif
 
+#ifdef HAVE_SIGNAL_H
+#include <signal.h>
+#else
+#error need signal.h
+#endif
+
 #if defined( HAVE_SYS_AUDIO_H )
 #include <sys/audio.h>
 #elif defined( HAVE_SYS_AUDIOIO_H )
@@ -102,7 +108,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: SolarisDspSource.cpp,v 1.2 2004/02/18 21:08:11 darkeye Exp $";
+static const char fileid[] = "$Id: SolarisDspSource.cpp 394 2007-01-14 16:28:42Z darkeye $";
 
 
 /* ===============================================  local function prototypes */
@@ -202,7 +208,8 @@ SolarisDspSource :: canRead ( unsigned int    sec,
                               unsigned int    usec )    throw ( Exception )
 {
     fd_set              fdset;
-    struct timeval      tv;
+    struct timespec     timespec;
+    sigset_t            sigset;
     int                 ret;
 
     if ( !isOpen() ) {
@@ -211,10 +218,15 @@ SolarisDspSource :: canRead ( unsigned int    sec,
 
     FD_ZERO( &fdset);
     FD_SET( fileDescriptor, &fdset);
-    tv.tv_sec  = sec;
-    tv.tv_usec = usec;
 
-    ret = select( fileDescriptor + 1, &fdset, NULL, NULL, &tv);
+    timespec.tv_sec  = sec;
+    timespec.tv_nsec = usec * 1000L;
+
+    // mask out SIGUSR1, as we're expecting that signal for other reasons
+    sigemptyset(&sigset);
+    sigaddset(&sigset, SIGUSR1);
+
+    ret = pselect( fileDescriptor + 1, &fdset, NULL, NULL, &timespec, &sigset);
     
     if ( ret == -1 ) {
         throw Exception( __FILE__, __LINE__, "select error");
@@ -263,19 +275,3 @@ SolarisDspSource :: close ( void )                  throw ( Exception )
 
 #endif // SUPPORT_SOLARIS_DSP
 
-
-/*------------------------------------------------------------------------------
- 
-  $Source: /cvsroot/darkice/darkice/src/SolarisDspSource.cpp,v $
-
-  $Log: SolarisDspSource.cpp,v $
-  Revision 1.2  2004/02/18 21:08:11  darkeye
-  ported to OpenBSD (real-time scheduling not yet supported)
-
-  Revision 1.1  2001/09/11 15:05:21  darkeye
-  added Solaris support
-
-
-  
-------------------------------------------------------------------------------*/
-
